[java-idp-plugin-oidc-rp] branch main updated: Make handler classnames consistent

Phil Smart philip.smart at jisc.ac.uk
Mon Dec 19 10:09:39 UTC 2022


This is an automated email from the git hooks/post-receive script.

philsmart pushed a commit to branch main
in repository java-idp-plugin-oidc-rp.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-plugin-oidc-rp.git;a=commit;h=be6c1951b7105433e811eb43f4d20187ad8c7077

The following commit(s) were added to refs/heads/main by this push:
     new be6c195  Make handler classnames consistent
be6c195 is described below

commit be6c1951b7105433e811eb43f4d20187ad8c7077
Author: Phil Smart <philip.smart at jisc.ac.uk>
AuthorDate: Mon Dec 19 10:09:36 2022 +0000

    Make handler classnames consistent
---
 .../rp/messaging/impl/{EncryptJWT.java => EncryptJWTHandler.java} | 6 +++---
 .../oidc/rp/messaging/impl/{SignJWT.java => SignJWTHandler.java}  | 6 +++---
 .../authn/OIDCRelyingParty/oidc-relying-party-authn-beans.xml     | 4 ++--
 .../plugin/authn/oidc/rp/impl/AuthorizationControllerTest.java    | 8 ++++----
 .../shibboleth/idp/plugin/authn/oidc/rp/impl/EncryptJWTTest.java  | 6 +++---
 .../impl/{EncryptJWTTest.java => EncryptJWTHandlerTest.java}      | 8 ++++----
 .../messaging/impl/{SignJWTTest.java => SignJWTHandlerTest.java}  | 6 +++---
 7 files changed, 22 insertions(+), 22 deletions(-)

diff --git a/idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWT.java b/idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTHandler.java
similarity index 99%
rename from idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWT.java
rename to idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTHandler.java
index 9ff9921..8d0a452 100644
--- a/idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWT.java
+++ b/idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTHandler.java
@@ -65,10 +65,10 @@ import net.shibboleth.utilities.java.support.primitive.StringSupport;
  * A consumer takes the {@link EncryptedJWT} and updates the correct object in the {@link MessageContext}.
  */
 //TODO encrypt action is unpleasent to look at
-public class EncryptJWT extends AbstractMessageHandler {
+public class EncryptJWTHandler extends AbstractMessageHandler {
     
     /** Class logger. */
-    @Nonnull private final Logger log = LoggerFactory.getLogger(EncryptJWT.class);
+    @Nonnull private final Logger log = LoggerFactory.getLogger(EncryptJWTHandler.class);
     
     /** Strategy used to locate the {@link SecurityParametersContext} to use for signing. */
     @Nonnull private Function<MessageContext, JWTSecurityParametersContext> securityParametersLookupStrategy;
@@ -87,7 +87,7 @@ public class EncryptJWT extends AbstractMessageHandler {
     
     
     /** Constructor.*/
-    public EncryptJWT() { 
+    public EncryptJWTHandler() { 
         logName = "not-specified";
         securityParametersLookupStrategy = new ChildContextLookup<>(JWTSecurityParametersContext.class);
     }
diff --git a/idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWT.java b/idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTHandler.java
similarity index 99%
rename from idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWT.java
rename to idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTHandler.java
index 7654400..6e97bd7 100644
--- a/idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWT.java
+++ b/idp-oidc-rp-impl/src/main/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTHandler.java
@@ -62,10 +62,10 @@ import net.shibboleth.utilities.java.support.primitive.StringSupport;
  * Action that signs a request object and sets it as the request object to the authentication request.
  */
 //TODO move to commons?
-public class SignJWT extends AbstractMessageHandler {
+public class SignJWTHandler extends AbstractMessageHandler {
     
     /** Class logger. */
-    @Nonnull private final Logger log = LoggerFactory.getLogger(SignJWT.class);
+    @Nonnull private final Logger log = LoggerFactory.getLogger(SignJWTHandler.class);
     
     /** Strategy used to locate the {@link SecurityParametersContext} to use for signing. */
     @Nonnull private Function<MessageContext, JWTSecurityParametersContext> securityParametersLookupStrategy;
@@ -92,7 +92,7 @@ public class SignJWT extends AbstractMessageHandler {
     @Nonnull private String logName;
     
     /** Constructor.*/
-    public SignJWT() {
+    public SignJWTHandler() {
         logName = "not-specified";
         securityParametersLookupStrategy = new ChildContextLookup<>(JWTSecurityParametersContext.class);        
     }
diff --git a/idp-oidc-rp-impl/src/main/resources/META-INF/net/shibboleth/idp/flows/authn/OIDCRelyingParty/oidc-relying-party-authn-beans.xml b/idp-oidc-rp-impl/src/main/resources/META-INF/net/shibboleth/idp/flows/authn/OIDCRelyingParty/oidc-relying-party-authn-beans.xml
index 22f69c7..d9a9942 100644
--- a/idp-oidc-rp-impl/src/main/resources/META-INF/net/shibboleth/idp/flows/authn/OIDCRelyingParty/oidc-relying-party-authn-beans.xml
+++ b/idp-oidc-rp-impl/src/main/resources/META-INF/net/shibboleth/idp/flows/authn/OIDCRelyingParty/oidc-relying-party-authn-beans.xml
@@ -269,7 +269,7 @@
                     class="net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.BuildPlainRequestObjectJWT"
                     scope="prototype" />
 
-                <bean id="SignRequestObject" class="net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.SignJWT"
+                <bean id="SignRequestObject" class="net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.SignJWTHandler"
                     scope="prototype" p:logName="RequestObject">
                     <property name="claimsToSignLookupStrategy">
                         <bean
@@ -282,7 +282,7 @@
                 </bean>
 
                 <bean id="EncryptRequestObject"
-                    class="net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.EncryptJWT" scope="prototype"
+                    class="net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.EncryptJWTHandler" scope="prototype"
                     p:logName="RequestObject">
                     <property name="payloadToEncryptLookupStrategy">
                         <bean
diff --git a/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/impl/AuthorizationControllerTest.java b/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/impl/AuthorizationControllerTest.java
index 12ebb26..96e28a6 100644
--- a/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/impl/AuthorizationControllerTest.java
+++ b/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/impl/AuthorizationControllerTest.java
@@ -94,8 +94,8 @@ import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.context.logic.JWTClaims
 import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.context.logic.PayloadFromRequestObjectLookupFunction;
 import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.AddStateHandler;
 import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.BuildPlainRequestObjectJWT;
-import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.EncryptJWT;
-import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.SignJWT;
+import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.EncryptJWTHandler;
+import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.SignJWTHandler;
 import net.shibboleth.idp.plugin.authn.test.flow.mock.IdPPropertyConfigurer;
 import net.shibboleth.idp.session.IdPSession;
 import net.shibboleth.idp.session.context.SessionContext;
@@ -307,13 +307,13 @@ public class AuthorizationControllerTest extends AbstractTestNGSpringContextTest
         
         final var addState = new AddStateHandler();
         addState.initialize();
-        final var signer = new SignJWT();
+        final var signer = new SignJWTHandler();
         signer.setClaimsToSignLookupStrategy(new JWTClaimsSetFromRequestObjectLookupFunction());
         signer.setJwtUpdateConsumer(new RequestObjectTokenUpdateStrategy());
         signer.initialize();
         final var buildRequestObjectJwt = new BuildPlainRequestObjectJWT();
         buildRequestObjectJwt.initialize();
-        final var encrypter = new EncryptJWT();
+        final var encrypter = new EncryptJWTHandler();
         encrypter.setPayloadToEncryptLookupStrategy(new PayloadFromRequestObjectLookupFunction());
         encrypter.setJwtUpdateConsumer(new RequestObjectTokenUpdateStrategy());
         encrypter.initialize();        
diff --git a/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/impl/EncryptJWTTest.java b/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/impl/EncryptJWTTest.java
index 1316845..a136638 100644
--- a/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/impl/EncryptJWTTest.java
+++ b/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/impl/EncryptJWTTest.java
@@ -44,7 +44,7 @@ import com.nimbusds.jose.jwk.gen.RSAKeyGenerator;
 import com.nimbusds.jwt.EncryptedJWT;
 import com.nimbusds.jwt.JWTClaimsSet;
 
-import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.EncryptJWT;
+import net.shibboleth.idp.plugin.authn.oidc.rp.messaging.impl.EncryptJWTHandler;
 import net.shibboleth.oidc.jwa.support.EncryptionConstants;
 import net.shibboleth.oidc.jwa.support.KeyManagementConstants;
 import net.shibboleth.oidc.security.JWTEncryptionParameters;
@@ -57,7 +57,7 @@ public class EncryptJWTTest extends AbstractOIDCTest {
     private static final String CLIENT_SECRET = "Xp2s5v8y/B?E(H+MbQeThWmYq3t6w9z$";
     
     /** Decrypt action to test.*/
-    private EncryptJWT action;
+    private EncryptJWTHandler action;
     
     /** The Security Params to use.*/
     private JWTSecurityParametersContext secContext;
@@ -69,7 +69,7 @@ public class EncryptJWTTest extends AbstractOIDCTest {
     @BeforeMethod
     public void setup() throws Exception {
         super.setup();
-        action = new EncryptJWT();       
+        action = new EncryptJWTHandler();       
         
         action.setPayloadToEncryptLookupStrategy(prc -> {
             
diff --git a/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTTest.java b/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTHandlerTest.java
similarity index 98%
rename from idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTTest.java
rename to idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTHandlerTest.java
index 6041dab..61759a9 100644
--- a/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTTest.java
+++ b/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/SignJWTHandlerTest.java
@@ -52,13 +52,13 @@ import net.shibboleth.oidc.security.context.JWTSecurityParametersContext;
  * 
  * <p>Note, These tests sign a RequestObject. </p>
  */
-public class SignJWTTest extends AbstractOIDCTest {
+public class SignJWTHandlerTest extends AbstractOIDCTest {
     
     /** A client_secret to use.*/
     @Nonnull private static final String CLIENT_SECRET = "Xp2s5v8y/B?E(H+MbQeThWmYq3t6w9z$";
     
     /** The signer to test.*/
-    private SignJWT signer;
+    private SignJWTHandler signer;
     
     /** The authn request.*/
     private OIDCAuthenticationRequest request;
@@ -67,7 +67,7 @@ public class SignJWTTest extends AbstractOIDCTest {
     @BeforeMethod
     public void setup() throws Exception {
         super.setup();
-        signer = new SignJWT();
+        signer = new SignJWTHandler();
         
         signer.setClaimsToSignLookupStrategy(mc -> {
             final OIDCAuthenticationRequest ar = (OIDCAuthenticationRequest)mc.getMessage();

diff --git a/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTTest.java b/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTHandlerTest.java
similarity index 98%
rename from idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTTest.java
rename to idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTHandlerTest.java
index 4ba0609..8148554 100644
--- a/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTTest.java
+++ b/idp-oidc-rp-impl/src/test/java/net/shibboleth/idp/plugin/authn/oidc/rp/messaging/impl/EncryptJWTHandlerTest.java
@@ -61,17 +61,17 @@ import net.shibboleth.oidc.security.JWTEncryptionParameters;
 import net.shibboleth.oidc.security.context.JWTSecurityParametersContext;
 
 /** 
  * Tests for the {@link EncryptJWT} message handler. 
  * 
  * <p>Note, These tests encrypt a RequestObject. </p>
  */
-public class EncryptJWTTest extends AbstractOIDCTest {
+public class EncryptJWTHandlerTest extends AbstractOIDCTest {
     
     /** A client_secret to use.*/
     @Nonnull private static final String CLIENT_SECRET = "Xp2s5v8y/B?E(H+MbQeThWmYq3t6w9z$";
     
     /** The signer to test.*/
-    private EncryptJWT encrypter;
+    private EncryptJWTHandler encrypter;
     
     /** The authn request.*/
     private OIDCAuthenticationRequest request;
@@ -80,7 +80,7 @@ public class EncryptJWTTest extends AbstractOIDCTest {
     @BeforeMethod
     public void setup() throws Exception {
         super.setup();
-        encrypter = new EncryptJWT();
+        encrypter = new EncryptJWTHandler();
         
         encrypter.setPayloadToEncryptLookupStrategy(mc -> {
             final OIDCAuthenticationRequest authnRequest = (OIDCAuthenticationRequest)mc.getMessage();
@@ -61,17 +61,17 @@ import net.shibboleth.oidc.security.JWTEncryptionParameters;
 
 /** 
- * Tests for the {@link EncryptJWT} message handler. 
+ * Tests for the {@link EncryptJWTHandler} message handler. 
  * 
  * <p>Note, These tests encrypt a RequestObject. </p>
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list